@@ -1,39 +1,37 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::MakeMaker::Fallback; # git description: v0.020-4-gee9a72d
+package Dist::Zilla::Plugin::MakeMaker::Fallback; # git description: v0.021-10-g8e57309
 # ABSTRACT: Generate a Makefile.PL containing a warning for legacy users
 # KEYWORDS: plugin installer MakeMaker Makefile.PL toolchain legacy ancient backcompat
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.021';
+our $VERSION = '0.022';
 
 use Moose;
-extends 'Dist::Zilla::Plugin::MakeMaker::Awesome' => { -version => '0.15' };
+extends 'Dist::Zilla::Plugin::MakeMaker::Awesome' => { -version => '0.26' };
 with 'Dist::Zilla::Role::AfterBuild' => { -excludes => 'dump_config' };
 
 use List::Util 'first';
 use version;
 use namespace::autoclean;
 
-# no point in bothering with this until we have config variables
-#around dump_config => sub
-#{
-#    my $orig = shift;
-#    my $self = shift;
-#
-#    my $config = $self->$orig;
-#
-#    $config->{+__PACKAGE__} = {
-#        # ...
-#    };
-#
-#    return $config;
-#};
+around dump_config => sub
+{
+    my ($orig, $self) = @_;
+    my $config = $self->$orig;
+
+    my $data = {
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
+    };
+    $config->{+__PACKAGE__} = $data if keys %$data;
+
+    return $config;
+};
 
 sub register_prereqs
 {
-    # block ExtUtils::MakeMaker from being added, since technically it should
-    # only be getting run if configure_requires is *not* being respected
+    # block ExtUtils::MakeMaker from being added, since we expect Build.PL to
+    # be preferred (so the requirements for *that* file are what matters)
 }
 
 sub after_build
@@ -60,11 +58,8 @@ around _build_WriteMakefile_args => sub
     };
 };
 
-around _build_MakeFile_PL_template => sub
+sub __preamble
 {
-    my $orig = shift;
-    my $self = shift;
-
     # this module file gets passed through a template itself at build time, so
     # we need to escape these template markers so they survive
 
@@ -105,8 +100,13 @@ EOW
     }
 }
 } # end BEGIN
-
 CODE
+}
+
+around _build_MakeFile_PL_template => sub
+{
+    my $orig = shift;
+    my $self = shift;
 
     my $string = $self->$orig(@_);
 
@@ -115,8 +115,10 @@ CODE
     $string =~ s/^use ExtUtils::MakeMaker\K[^\n]+;$/;/m;
 
     # splice in our stuff after the preamble bits
-    $string =~ m/use warnings;\n\n/g;
-    return substr($string, 0, pos($string)) . $code . substr($string, pos($string));
+    $self->log_fatal('failed to find position in Makefile.PL to munge!')
+        if $string !~ m/\{\{ \$header \}\}\n/g;
+
+    return substr($string, 0, pos($string)) . $self->__preamble . substr($string, pos($string));
 };
 
 sub test
@@ -245,7 +247,7 @@ Dist::Zilla::Plugin::MakeMaker::Fallback - Generate a Makefile.PL containing a w
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -351,7 +353,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-irc://irc.perl.org/#distzilla.
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
